breed [stocks stock]

breed [flows flow]

breed [particles particle]

flows-own [ flowtype outflownum ]

particles-own [ status life particletype outflow-num]

globals [ counter inflow-proportion proportion-out-1 proportion-out-2 prop-1-list prop-2-list outflow-recovered outflow-deaths]


to setup

  clear-all
  reset-ticks
  create-stocks 1
  [
    set shape "square"
    set size 15
    set color yellow
  ] ; end of stock creation

  ;create inflow
  create-flows 1
  [
    set shape "rectangle"
    set size 15
    set color white
    let x [xcor] of one-of stocks
    let z [size] of one-of stocks
    set xcor x + z / 2
    set flowtype "i"
    set outflownum -1 ;negative to represent inflow
  ] ; end of inflow creation

  ;create outflow 1
  create-flows 1
  [
    set shape "rectangle"
    set size 15
    set color green
    let x [xcor] of one-of stocks
    let z [size] of one-of stocks
    set xcor x - z / 2 - 1
    set ycor 2
    set flowtype "o"
    set outflownum 1
  ] ; end of outflow 1 creation

  ;create outflow 2
  create-flows 1
  [
    set shape "rectangle"
    set size 15
    set color blue
    let x [xcor] of one-of stocks
    let z [size] of one-of stocks
    set xcor x - z / 2 - 1
    set ycor -2
    set flowtype "o"
    set outflownum 2
  ] ;end of outflow 2 creation

  ;Assign labels for outflows
  ask patch ([xcor] of one-of stocks - [size] of one-of stocks / 2 - 1) 3 [set plabel "Recovery"]
  ask patch ([xcor] of one-of stocks - [size] of one-of stocks / 2 - 1) -1 [set plabel "Deaths"]

  ;initialize variables
  set inflow-proportion 0
  set proportion-out-1 0
  set proportion-out-2 0
  set prop-1-list [0 0 0 0 0 0 0] ; to calculate seven days moving average
  set prop-2-list [0 0 0 0 0 0 0] ;to calculate seven days moving average

end


to go

  ;stop simulation if ticks exceed 150 ticks
  if ticks >= 150 [stop]

  ;set xcor values for particles flowing out from the stock
  let oxlist (range -7.5 -5 0.1)

  ; update life of particles in the stock
  ask particles with [status = "stock"]
  [
    set life life + 1
  ] ;end of life update


  ; Move particles designated as outflow in previous tick to respective outflows and ask them to die
  ask particles with [status = "out" and outflow-num = 1]
  [
    set xcor one-of oxlist
    set ycor 2
    set outflow-recovered count particles with [status = "out" and outflow-num = 1]
  ] ;end of outflow 1 particle transfer

  ask particles with [status = "out" and outflow-num = 2]
  [
    set xcor one-of oxlist
    set ycor -2
    set outflow-deaths count particles with [status = "out" and outflow-num = 2]
  ] ;end of outflow 2 particle transfer

  ;calculate proportion of mild cases in each outflow
  let total-out-1 count particles with [particletype = 1 and outflow-num = 1] + count particles with [particletype = 2 and outflow-num = 1]
  let total-out-2 count particles with [particletype = 1 and outflow-num = 2] + count particles with [particletype = 2 and outflow-num = 2]
  if total-out-1 > 0 [set proportion-out-1 count particles with [particletype = 1 and outflow-num = 1] / total-out-1]
  if total-out-2 > 0 [set proportion-out-2 count particles with [particletype = 1 and outflow-num = 2] / total-out-2]

  ;Store values of fraction mild cases in each stream for seven days
  set prop-1-list replace-item (ticks mod 7) prop-1-list proportion-out-1
  set prop-2-list replace-item (ticks mod 7) prop-2-list proportion-out-2

  ;ask particles exiting through the outflows to die
  ask particles with [status = "out"] [die]


  ; inflow
  ask flows with [flowtype = "i"]
  [
    ;hatch particles representing recovery cases i.e. mild cases
    hatch-particles round inflow * precision (1 - Fraction_Severe_Cases) 2
    [
      set shape "circle"
      set particletype 1
      set color red
      set size 0.3
      set outflow-num 0
      set status "in"
    ] ;end of creation of mild case agents

    ;hatch particles representing death cases i.e. severe cases
    hatch-particles round inflow * Fraction_Severe_cases
    [
      set shape "circle"
      set color red
      set particletype 2
      set color green
      set size 0.3
      set outflow-num 0
      set status "in"
    ] ;end of creation of severe case agents

    ;move newly hatched particles into the stock
    ask particles with [status = "in"] [
      facexy 0 0
      forward 4
      set status "stock"
      set life 0
      let xlist (range -4.5 4.5 0.1)
      let ylist (range -4.5 4.5 0.1)
      set xcor one-of xlist
      set ycor one-of ylist
    ] ;end of transfer of inflow particles to stock
  ] ;end of inflow procedure


  ;outflow

  ;outflow - two stock version
  if Number-of-Stocks = "Two Stock"
  [
    let n count particles with [status = "stock" and particletype = 1]
    let recoveries round (precision (1 / time-delay-for-recovery) 2 * n) ;fractional recovery flowrate
    ask n-of recoveries particles with [status = "stock" and particletype = 1] [set status "out" set outflow-num 1]
    let m count particles with [status = "stock" and particletype = 2]
    let deaths round (precision (1 / time-delay-for-death) 2 * m) ;fractional death flowrate
    ask n-of deaths particles with [status = "stock" and particletype = 2] [set status "out" set outflow-num 2]
  ] ;end of two stock version outflow

  ;outflow - single stock version
  ; In single stock version, the particles are fully mixed and hence all unique characteristics is lost
  ; The individual particle types are maintained only to highlight how the particles behave in single stock condition
  if Number-of-Stocks = "Single Stock"
  [
    let n count particles with [status = "stock"]
    let recoveries round (precision (1 / time-delay-for-recovery) 2 * n)
    ask n-of recoveries particles with [status = "stock"] [set status "out" set outflow-num 1]
    let deaths round (precision (1 / time-delay-for-death) 2 * n)
    ask n-of deaths particles with [status = "stock"] [set status "out" set outflow-num 2]
  ] ;end of single stock version outflow

  tick

end
@#$#@#$#@
GRAPHICS-WINDOW
82
16
519
454
-1
-1
13.0
1
10
1
1
1
0
1
1
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
1205
34
1272
67
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
669
10
898
70
inflow
100.0
1
0
Number

BUTTON
1206
82
1269
115
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
568
231
930
499
Stock
time
particles
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Total" 1.0 0 -14070903 true "" "plot count particles with [status = \"stock\" or status = \"out\"]"
"MildCases" 1.0 0 -7500403 true "" "plot count particles with [status = \"stock\" or status = \"out\" and particletype = 1]"
"SevereCases" 1.0 0 -2674135 true "" "plot count particles with [status = \"stock\" or status = \"out\" and particletype = 2]"

INPUTBOX
668
84
788
144
time-delay-for-recovery
5.0
1
0
Number

INPUTBOX
809
84
939
144
time-delay-for-death
20.0
1
0
Number

PLOT
968
235
1299
497
Outflows
time
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Recoveries" 1.0 0 -7500403 true "" "plot outflow-recovered"
"Deaths" 1.0 0 -5298144 true "" "plot outflow-deaths"

MONITOR
600
174
872
219
Fraction Mild Case Agents in Recovery Outflow
precision mean prop-1-list 2
17
1
11

MONITOR
888
174
1150
219
 Fraction Mild Case Agents in Deaths Outflow
precision mean prop-2-list 2
17
1
11

INPUTBOX
951
85
1106
145
Fraction_Severe_Cases
0.2
1
0
Number

BUTTON
1207
126
1284
159
go-once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
922
12
1060
57
Number-of-Stocks
Number-of-Stocks
"Single Stock" "Two Stock"
0

@#$#@#$#@
## Purpose and Patterns

This model was developed to explore the reasons for different outputs generated by a set of System Dynamics models. The main objective was to investigate the conditions under which a single-stock single-inflow two-outflow System Dynamic model structure is valid. One of the conditions explored is when the inflow is not homogeneous i.e. it contains entities that are qualitatively different (for example, mild infection cases and severe infection cases). It was observed that single-stock model and comparable two-stock model (where mild cases flow to dedicated mild cases stock and severe cases flow to severe cases stock) give different values for outflows and stock levels. Since stock and flow models does not provide details of what exactly goes inside the structure, it was decided to replicate these model structure as agent-based models to help identify the reason for this discrepancy.

## Entities, State Variables and Scales

The environment is a 33 x 33 grid.

There are three classes of agents in the model. First is a stock. The agent represents a stock in the System Dynamics model. Other than its shape matching shape of a stock, it does not possess any other attributes relevant for the simulation.

Second class of agents is flows. These agents represent inflow and outflows in System Dynamics models and hence has a rectangular shape. There are two attributes for this agent.Flowtype indicates whether the flow is an inflow or outflow. Outflownum indicates whether the outflow represents Recoveries or Deaths.

Final class of agents is particle. Each particle represents a person. A particle is created at the inflow, moves over to the stock and exits through the outflow as per the policy used in the model. Each particle has the following attributes:

  Status: Indicates whether the particle is at the inflow, stock or at the outflow

  Life: Total residence time within the stock

  Particletype: Indicates whether the particle represents Mild Case (value = 1 and color    = red) and Severe Case (value = 2 and color = green)

  Outflow-num: Indicates the outflow to be taken by the particle while it exits the stock

The following parameters are used in the model:

Inflow: Number of new infections per day. The default value is 100

Fraction Severe Cases: The fraction of new infections that are severe cases (these agents will die). The remaining fraction are mild cases and will eventually recover. The default value is 0.2

Time-delay-for-deaths: Average time taken in days for a severe case, from the onset of infection, to die. The default value is 20 days.

Time-delay-for-recoveries: Average time taken in days for a mild case, fromt the onset of infection, to recover. The default value is 5 days.

The Number-of-Stocks chooser is for selecting the Single Stock case or the Two Stock Case. In the Single Stock Case, there are no restrictions on the agents in selecting the outflow through which they can exit the stock. In the Two Stock Case, the mild case agents can exit only through the Recoveries outflow and severe case agents can exit only through the Deaths outflow.

The time step used in the model is days. The model is programed to stop once the ticks reach 150.


## Process overview and scheduling

The following actions are executed once per time step, in the order given below:
1. Update life of particles in stock.

2. Particles earmarked for outflow move to respective outflows. In a subsequent step it will be shown that each particle that is marked for outflow is assigned to a particular outflow i.e. Recoveries or Deaths. Count of such particles exiting through each of the outflows is made and is used to calculate the fraction of mild cases in each of the outflows. Values of fraction mild cases in each stream for seven days is stored in two separate lists. This list is maintained to calculate the seven day moving average of fraction mild cases in each outflow stream. The particle is then asked to die.

3. The flow agent marked for inflow hatches particles equal to the value of inflow set in the interface. Out of this, a fraction of particles equal to the (1 - Fraction Severe Cases (provided in interface)) are agents representing mild cases. Remaining particles are agents representing mild cases. All the newly hatched particles are moved into the stock.

4. Outflows are calculated under two scenarios namely Two stock version and Single stock version.

In the two stock case, number of mild cases in stock and number of severe cases in stock are counted separately. Number of recovered during the time step is then calculated by multiplying number of mild cases in stock with the fraction 1 / time-delay-for-recovery. These recovered mild cases are marked for outflow and assigned to the Recoveries outflow. Similarly, number of deaths is calculated by multiplying number of severe cases in stock with the fraction 1 / time-delay-for-death. Death cases are marked for outflow and assigned to Deaths outflow.

In the single stock case, a count of all the particles in the stock, irrespective of whether they are severe cases or mild cases, is taken.  Number of recovered during the time step is then calculated by multiplying this total number of particles in stock with the fraction 1 / time-delay-for-recovery. These recovered cases are marked for outflow and assigned to the Recoveries outflow. Similarly, number of deaths is calculated by multiplying total number of particles in stock with the fraction 1 / time-delay-for-death. Such death cases are marked for outflow and assigned to Deaths outflow.


## Design Concepts

Emergence: Equilibrium stock level and thereby the corresponding equilirbrium outflow is an emergent phenomena. In the single stock case, there are no constraints acting on the agents and they can exit through any one of the two outflows. The actual number of agents exiting through each of these outflows during each time period is therefore determined based on the overall stock of agents. In the two stock case, a particular type of agent can flow out through only the desginated outflow. Outflows quantities are therefore determined by the stock of respective agents (and not the overall stock of agents).

Agents do not have objectives nor sensing function in this model. They also do not perform prediction , interaction nor adaptive behavior in the model.

Stochasticity: Randomness is used in multiple instances to call particles (agents). Since there are no interaction between agents, randomness in the call order does not have any impact on the model outcome. 

Another area where randomness is applied is in the selection of agents for outflow over a time step. In this case randomness essentially represents probability of transition of agents in stock from state = "stock" to state = "out". The transition probabilities for Recoveries and Deaths outflows (over a time step) are represented by the fractions 1 / time-delay-for-recovery and 1 / time-delay-for-death, respectively.

The are no collectives in this model.

Observation: 
One plot shows the value of stock over time. It also provides disaggregated detail of the number of agents of each type within the stock.

Next plot shows the value of Recoveries and Deaths outflow over time.

There are two monitors used in the interface. First monitor shows Fraction Mild Cases in the Recoveries outflow and the second monitor shows Fraction Mild Cases in Deaths outflow.


## Initialization

The stock, inflow and outflow agents are initialized when the model is setup. The default value of parameters are:
Inflow = 100 patients per day
Time-delay-for-recovery = 5 days
Time-delay-for-death = 20 days
Fraction_Severe_Cases = 0.2

The chooser 'Number-of-Stocks' can be used to select Single-Stock version or the Two-Stock version.

## Input Data

No input data is used in this model.

## Submodels

There are no submodels used in the model. All the processes are captured directly within the go procedure.

## Credits and References
The model uses the concepts of stocks and flows used in the field of System Dynamics

1.Forrester, J. W. (1999). Industrial dynamics. Waltham, Mass: Pegasus Communications.	

2.Sterman, J. D. (2000). Business dynamics: Systems thinking and modeling for a complex world. Boston: Irwin/McGraw-Hill.

The model formulation utilized the ODD protocol provided in the following reference:

3.Railsback, S. F., & Grimm, V. (2019). Agent-Based and Individual-Based Modeling: A Practical Introduction (Second edition), Princeton University Press.

## How to Cite
This model is a part of the Poster titled 'Role of Stock constraint in single-stock single-inflow two-outflow System Dynamics model structures' presented at the 2022 International System Dynamics Conference held at Frankfurt & Online from July 18-22, 2022.

To cite:

- K.V.,Pradeesh Kumar (2022). Agent Based Model of simple Single-Stock and Two-Stock System Dynamics Structures.

@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

rectangle
false
0
Rectangle -7500403 true true 105 135 225 165

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.2.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
